==> openGion6.4.0.3_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF90S.sql <==
/****************************************************************************/
/* GF90 ( 青紙ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2015/11/16 16:20:03                                            */
/****************************************************************************/
CREATE TABLE GF90 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , NMSYS        VARCHAR2 ( 200 )                                        /*  20 ｼｽﾃﾑ名       */
 , PGID         VARCHAR2 (  30 )                    NOT NULL            /*  30 PG-ID        */
 , SEQ          NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  40 順           */
 , NMPG         VARCHAR2 ( 200 )                                        /*  50 処理名       */
 , PGLANG       VARCHAR2 (  10 )                                        /*  60 言語         */
 , SIYOSAKU     VARCHAR2 (  10 )                                        /*  70 仕様作成者   */
 , PGSAKU       VARCHAR2 (  10 )                                        /*  80 PG作成者     */
 , PGKEN        VARCHAR2 (  10 )                                        /*  90 検証者       */
 , DYSAKU       VARCHAR2 (   8 )                                        /* 100 作成日       */
 , DYKAN        VARCHAR2 (   8 )                                        /* 110 完成日       */
 , DYKEN        VARCHAR2 (   8 )                                        /* 120 検証日       */
 , CDSAKU       VARCHAR2 (  30 )                                        /* 130 作番CD       */
 , GUITYPE      VARCHAR2 (   2 )                                        /* 140 画面ﾀｲﾌﾟ     */
 , HPGID        VARCHAR2 (  30 )                                        /* 150 雛形PGID     */
 , SPGID        VARCHAR2 (  30 )                                        /* 160 参照PGID     */
 , FGGAMEN      VARCHAR2 (   1 )                                        /* 170 画面編集FG   */
 , GAIYO        CLOB                                                    /* 180 処理概要     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K NEXT 16K );

CREATE SEQUENCE GF90S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF90T00 
  BEFORE INSERT ON GF90
  FOR EACH ROW 
  BEGIN 
    SELECT GF90S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/

==> openGion6.4.1.0_dev.zip: uap/webapps/gf/db/oracle/sql/install/01_TABLE/GF90S.sql <==
/****************************************************************************/
/* GF90 ( 青紙ﾃｰﾌﾞﾙ )                                                       */
/*                                                                          */
/* Created : 2016/01/07 17:07:19                                            */
/****************************************************************************/
CREATE TABLE GF90 (
   SYSTEM_ID    VARCHAR2 (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID       */
 , NMSYS        VARCHAR2 ( 200 )                                        /*  20 ｼｽﾃﾑ名       */
 , PGID         VARCHAR2 (  30 )                    NOT NULL            /*  30 PG-ID        */
 , SEQ          NUMBER   (   7 )        DEFAULT 0   NOT NULL            /*  40 順           */
 , NMPG         VARCHAR2 ( 200 )                                        /*  50 処理名       */
 , PGLANG       VARCHAR2 (  10 )                                        /*  60 言語         */
 , SIYOSAKU     VARCHAR2 (  10 )                                        /*  70 仕様作成者   */
 , PGSAKU       VARCHAR2 (  10 )                                        /*  80 PG作成者     */
 , PGKEN        VARCHAR2 (  10 )                                        /*  90 検証者       */
 , DYSAKU       VARCHAR2 (   8 )                                        /* 100 作成日       */
 , DYKAN        VARCHAR2 (   8 )                                        /* 110 完成日       */
 , DYKEN        VARCHAR2 (   8 )                                        /* 120 検証日       */
 , CDSAKU       VARCHAR2 (  30 )                                        /* 130 作番CD       */
 , GUITYPE      VARCHAR2 (   2 )                                        /* 140 画面ﾀｲﾌﾟ     */
 , HPGID        VARCHAR2 (  30 )                                        /* 150 雛形PGID     */
 , SPGID        VARCHAR2 (  30 )                                        /* 160 参照PGID     */
 , FGGAMEN      VARCHAR2 (   1 )                                        /* 170 画面編集FG   */
 , GAIYO        CLOB                                                    /* 180 処理概要     */
 , UNIQ         NUMBER   (   9 )        DEFAULT 0   NOT NULL            /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ          VARCHAR2 (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET        VARCHAR2 (  14 )                                        /* 820 登録日時     */
 , PGSET        VARCHAR2 (  10 )                                        /* 830 作成PG       */
 , PGPSET       VARCHAR2 (  10 )                                        /* 840 作成親PG     */
 , USRSET       VARCHAR2 (  10 )                                        /* 850 作成社員     */
 , DYUPD        VARCHAR2 (  14 )                                        /* 860 更新日時     */
 , PGUPD        VARCHAR2 (  10 )                                        /* 870 更新PG       */
 , PGPUPD       VARCHAR2 (  10 )                                        /* 880 更新親PG     */
 , USRUPD       VARCHAR2 (  10 )                                        /* 890 更新者       */
)
TABLESPACE GETBL01
STORAGE( INITIAL 16K );

CREATE SEQUENCE GF90S00 
  INCREMENT BY 1 START WITH 1 MAXVALUE 999999999 CYCLE NOCACHE;

CREATE OR REPLACE TRIGGER GF90T00 
  BEFORE INSERT ON GF90
  FOR EACH ROW 
  BEGIN 
    SELECT GF90S00.NEXTVAL INTO :NEW.UNIQ FROM DUAL; 
  END; 
/
